tiled.readers.hdf5.HDF5Reader
=============================

.. currentmodule:: tiled.readers.hdf5

.. autoclass:: HDF5Reader

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HDF5Reader.__init__
      ~HDF5Reader.authenticated_as
      ~HDF5Reader.from_file
      ~HDF5Reader.get
      ~HDF5Reader.items
      ~HDF5Reader.keys
      ~HDF5Reader.search
      ~HDF5Reader.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~HDF5Reader.access_policy
      ~HDF5Reader.authenticated_identity
      ~HDF5Reader.items_indexer
      ~HDF5Reader.keys_indexer
      ~HDF5Reader.metadata
      ~HDF5Reader.values_indexer
   
   